==> camunda-engine-7.2.0-sources.jar: org/camunda/bpm/engine/impl/cmmn/cmd/GetDeploymentCaseDefinitionCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmmn.cmd;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;

import java.io.Serializable;

import org.camunda.bpm.engine.impl.context.Context;
import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;
import org.camunda.bpm.engine.repository.CaseDefinition;

/**
 * @author Roman Smirnov
 *
 */
public class GetDeploymentCaseDefinitionCmd implements Command<CaseDefinition>, Serializable {

  private static final long serialVersionUID = 1L;
  protected String caseDefinitionId;

  public GetDeploymentCaseDefinitionCmd(String caseDefinitionId) {
    this.caseDefinitionId = caseDefinitionId;
  }

  public CaseDefinition execute(CommandContext commandContext) {
    ensureNotNull("caseDefinitionId", caseDefinitionId);

    return Context
      .getProcessEngineConfiguration()
      .getDeploymentCache()
      .findDeployedCaseDefinitionById(caseDefinitionId);
  }

}

==> camunda-engine-7.9.0-sources.jar: org/camunda/bpm/engine/impl/cmmn/cmd/GetDeploymentCaseDefinitionCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmmn.cmd;

import static org.camunda.bpm.engine.impl.util.EnsureUtil.ensureNotNull;

import java.io.Serializable;

import org.camunda.bpm.engine.impl.cfg.CommandChecker;
import org.camunda.bpm.engine.impl.cmmn.entity.repository.CaseDefinitionEntity;
import org.camunda.bpm.engine.impl.context.Context;
import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;
import org.camunda.bpm.engine.repository.CaseDefinition;

/**
 * @author Roman Smirnov
 *
 */
public class GetDeploymentCaseDefinitionCmd implements Command<CaseDefinition>, Serializable {

  private static final long serialVersionUID = 1L;
  protected String caseDefinitionId;

  public GetDeploymentCaseDefinitionCmd(String caseDefinitionId) {
    this.caseDefinitionId = caseDefinitionId;
  }

  public CaseDefinition execute(CommandContext commandContext) {
    ensureNotNull("caseDefinitionId", caseDefinitionId);

    CaseDefinitionEntity caseDefinition = Context.getProcessEngineConfiguration().getDeploymentCache()
        .findDeployedCaseDefinitionById(caseDefinitionId);

    for(CommandChecker checker : commandContext.getProcessEngineConfiguration().getCommandCheckers()) {
      checker.checkReadCaseDefinition(caseDefinition);
    }

    return caseDefinition;
  }

}
